@@ -474,7 +474,8 @@ def obtain_neighborhood_composition(dataset,CropConfPheno,CropConfTissueComm):
     heatmapInteractivityMatrix_Fig.savefig(dataset.bioInsights_dir_cell_types+'Neighborhoods/heatmap_InteractivityMat_Norm.png',dpi=600) 
 
 def Area_to_Neighborhood_to_Phenotype(dataset,clusters,IndexAndClass, ClusteringThreshold):
-    # Patient-Type            
+    
+    # Initialize variables for neighborhood and areas            
     Area_to_Neigh = np.zeros((clusters[-1],clusters[-2]))                
     Neigh_to_Pheno = np.zeros((clusters[-2],clusters[-3]))            
 
@@ -483,34 +484,42 @@ def Area_to_Neighborhood_to_Phenotype(dataset,clusters,IndexAndClass, Clustering
         try:
             neigh_to_area_assignment = np.load(osp.join(dataset.processed_dir_cell_types,'cluster_assignment_Index_{}_ClustLvl_{}.npy'.format(idxclster[1], clusters[-1])))                
             patch_to_neigh_assignment = np.load(osp.join(dataset.processed_dir_cell_types,'cluster_assignmentPerPatch_Index_{}_0_ClustLvl_{}.npy'.format(idxclster[1], clusters[-2])))        
-            patch_to_pheno_assignment = np.load(osp.join(dataset.processed_dir_cell_types,'cluster_assignmentPerPatch_Index_{}_0_ClustLvl_{}.npy'.format(idxclster[1], clusters[-3])))                
+            patch_to_pheno_assignment = np.load(osp.join(dataset.processed_dir_cell_types,'cluster_assignmentPerPatch_Index_{}_0_ClustLvl_{}.npy'.format(idxclster[1], clusters[-3])))         
+            data = dataset.get(idxclster[1],0)
+            patch_to_neigh_assignment[data.num_nodes:,:] = 0
+            patch_to_pheno_assignment[data.num_nodes:,:] = 0
         except:
             continue
-        # Assign Neigh_to_Area
-        neigh_to_area_assignment = neigh_to_area_assignment - neigh_to_area_assignment.min(-2)
-        neigh_to_area_assignment = neigh_to_area_assignment / (neigh_to_area_assignment.max(-2,keepdims=True)+1e-12)        
+
+        # Normalize each pheno, neigh, area
+        neigh_to_area_assignment = neigh_to_area_assignment-neigh_to_area_assignment.min(0,keepdims=True)
+        neigh_to_area_assignment = neigh_to_area_assignment/neigh_to_area_assignment.max(0,keepdims=True)
+        patch_to_neigh_assignment = patch_to_neigh_assignment-patch_to_neigh_assignment.min(0,keepdims=True)
+        patch_to_neigh_assignment = patch_to_neigh_assignment/patch_to_neigh_assignment.max(0,keepdims=True)
+        patch_to_pheno_assignment = patch_to_pheno_assignment-patch_to_pheno_assignment.min(0,keepdims=True)
+        patch_to_pheno_assignment = patch_to_pheno_assignment/patch_to_pheno_assignment.max(0,keepdims=True)
+
+        # Assign area to neighborhood
         Area_to_Neigh += np.transpose(neigh_to_area_assignment)
-        # Assign Patch_to_Neigh
-        PercTHrsl_neigh = np.percentile(patch_to_neigh_assignment,axis=0,q=ClusteringThreshold)
-        PercTHrsl_pheno = np.percentile(patch_to_pheno_assignment,axis=0,q=ClusteringThreshold)
+        
+        # Calculate percentile        
+        PercTHrsl_area = np.percentile(neigh_to_area_assignment[:data.num_nodes,:],axis=0,q=ClusteringThreshold)
+        PercTHrsl_neigh = np.percentile(patch_to_neigh_assignment[:data.num_nodes,:],axis=0,q=ClusteringThreshold)
+        PercTHrsl_pheno = np.percentile(patch_to_pheno_assignment[:data.num_nodes,:],axis=0,q=ClusteringThreshold)
+        
+        # Assign neighborhood
+        for i in range(neigh_to_area_assignment.shape[1]):
+            neigh_to_area_assignment[:,i][PercTHrsl_area[i]>=neigh_to_area_assignment[:,i]] = 0             
+
+        # Assign neighborhood
         for i in range(patch_to_neigh_assignment.shape[1]):
             patch_to_neigh_assignment[:,i][PercTHrsl_neigh[i]>=patch_to_neigh_assignment[:,i]] = 0 
+        
+        # Assign Phenotype
         for i in range(patch_to_pheno_assignment.shape[1]):
-            patch_to_pheno_assignment[:,i][PercTHrsl_pheno[i]>=patch_to_pheno_assignment[:,i]] = 0         
-        Neigh_to_Pheno += np.matmul(np.transpose(patch_to_neigh_assignment),patch_to_pheno_assignment)
+            patch_to_pheno_assignment[:,i][PercTHrsl_pheno[i]>=patch_to_pheno_assignment[:,i]] = 0                 
 
-    # Save heatmap Neigh_to_Pheno
-    plt.close()
-    plt.figure()
-    sns.set(font_scale=1.1)
-    row_colors_Neigh=cm.jet_r(range(0,255,int(255/clusters[1])))[:,:3]
-    yticklabels_Neigh = ['N'+str(i+1) for i in range(clusters[1])]
-    col_colors_Pheno=cm.jet_r(range(0,255,int(255/clusters[0])))[:,:3]
-    xticklabels_Pheno = ['P'+str(i+1) for i in range(clusters[0])]
-    Neigh_to_Pheno = Neigh_to_Pheno/(Neigh_to_Pheno.sum(1,keepdims=True)+1e-16)
-    h_E_Fig = sns.clustermap(Neigh_to_Pheno.transpose(),col_cluster=True, row_cluster=True, col_colors=row_colors_Neigh,
-                                row_colors=col_colors_Pheno,yticklabels=xticklabels_Pheno,xticklabels=yticklabels_Neigh, linewidths=0.5, cmap="bwr")            
-    h_E_Fig.savefig(dataset.bioInsights_dir_cell_types + 'Neighborhoods/heatmap_Phenotype_composition_of_neighborhoods_Raw_Thrs{}.png'.format(str(ClusteringThreshold)),dpi=600) 
+        Neigh_to_Pheno += np.matmul(np.transpose(patch_to_neigh_assignment[:data.num_nodes,:]),patch_to_pheno_assignment[:data.num_nodes,:])
 
     # Save heatmap Neigh_to_Pheno Normalized
     plt.close()
@@ -520,26 +529,11 @@ def Area_to_Neighborhood_to_Phenotype(dataset,clusters,IndexAndClass, Clustering
     yticklabels_Neigh = ['N'+str(i+1) for i in range(clusters[1])]
     col_colors_Pheno=cm.jet_r(range(0,255,int(255/clusters[0])))[:,:3]
     xticklabels_Pheno = ['P'+str(i+1) for i in range(clusters[0])]
-    Neigh_to_Pheno = stats.zscore(Neigh_to_Pheno,axis=0)
+    Neigh_to_Pheno = Neigh_to_Pheno/Neigh_to_Pheno.sum(1,keepdims=True)*100
     Neigh_to_Pheno[np.isnan(Neigh_to_Pheno)] = 0
     h_E_Fig = sns.clustermap(Neigh_to_Pheno.transpose(),col_cluster=True, row_cluster=True, col_colors=row_colors_Neigh,
-                                row_colors=col_colors_Pheno,yticklabels=xticklabels_Pheno,xticklabels=yticklabels_Neigh, vmin=-2, vmax=2, linewidths=0.5, cmap="bwr")            
-    h_E_Fig.savefig(dataset.bioInsights_dir_cell_types + 'Neighborhoods/heatmap_Phenotype_composition_of_neighborhoods_Norm_Thrs{}.png'.format(str(ClusteringThreshold)),dpi=600) 
-
-    # Save heatmap Area_to_Neigh
-    plt.close()
-    plt.figure()
-    sns.set(font_scale=1.1)
-    row_colors_Area=cm.jet_r(range(0,255,int(255/clusters[2])))[:,:3]
-    yticklabels_Area = ['A'+str(i+1) for i in range(clusters[2])]
-    col_colors_Neigh=cm.jet_r(range(0,255,int(255/clusters[1])))[:,:3]
-    xticklabels_Neigh = ['N'+str(i+1) for i in range(clusters[1])]
-    Area_to_Neigh = Area_to_Neigh/(Area_to_Neigh.sum(1,keepdims=True)+1e-16)
-    h_E_Fig = sns.clustermap(Area_to_Neigh.transpose(),col_cluster=True, row_cluster=True, col_colors=row_colors_Area,
-                                row_colors=col_colors_Neigh,yticklabels=xticklabels_Neigh,xticklabels=yticklabels_Area, linewidths=0.5, cmap="bwr")            
-    if not os.path.exists(dataset.bioInsights_dir_cell_types+'Areas/'):
-        os.mkdir(dataset.bioInsights_dir_cell_types+'Areas/')
-    h_E_Fig.savefig(dataset.bioInsights_dir_cell_types + 'Areas/heatmap_Neighborhood_composition_of_Areas_Raw.png',dpi=600) 
+                                row_colors=col_colors_Pheno,yticklabels=xticklabels_Pheno,xticklabels=yticklabels_Neigh, linewidths=0.5, cmap="bwr")            
+    h_E_Fig.savefig(dataset.bioInsights_dir_cell_types + 'Neighborhoods/heatmap_Phenotype_composition_of_neighborhoods_Perc_Thrs{}.png'.format(str(ClusteringThreshold)),dpi=600) 
 
     # Save heatmap Neigh_to_Pheno Normalized
     plt.close()
@@ -549,8 +543,8 @@ def Area_to_Neighborhood_to_Phenotype(dataset,clusters,IndexAndClass, Clustering
     yticklabels_Area = ['A'+str(i+1) for i in range(clusters[2])]
     col_colors_Neigh=cm.jet_r(range(0,255,int(255/clusters[1])))[:,:3]
     xticklabels_Neigh = ['N'+str(i+1) for i in range(clusters[1])]
-    Area_to_Neigh = stats.zscore(Area_to_Neigh,axis=0)
+    Area_to_Neigh = Area_to_Neigh/Area_to_Neigh.sum(1,keepdims=True)*100    
     Area_to_Neigh[np.isnan(Area_to_Neigh)] = 0
     h_E_Fig = sns.clustermap(Area_to_Neigh.transpose(),col_cluster=True, row_cluster=True, col_colors=row_colors_Area,
                                 row_colors=col_colors_Neigh,yticklabels=xticklabels_Neigh,xticklabels=yticklabels_Area, linewidths=0.5, cmap="bwr")            
-    h_E_Fig.savefig(dataset.bioInsights_dir_cell_types + 'Areas/heatmap_Neighborhood_composition_of_Areas_Norm.png',dpi=600) 
+    h_E_Fig.savefig(dataset.bioInsights_dir_cell_types + 'Areas/heatmap_Neighborhood_composition_of_Areas_Perc.png',dpi=600) 
