@@ -45,7 +45,7 @@ class NaroNet:
         utilz.initialization_params(self.dataset,self.args,self.num_features, self.model)    
 
     def visualize_results(self):
-        self.dataset.visualize_results(self.model,self.args['clusters'], self.IndexAndClass,self.mean_STD, self.args)
+        self.dataset.visualize_results(self.args['clusters'], self.IndexAndClass)
 
     def initialize_cross_validation(self):
         '''
@@ -273,6 +273,25 @@ class NaroNet:
 
         # Show epoch information and save it into a file
         self.dict_epoch = utilz.showAndSaveEpoch(self,train_results,validation_results,self.fold,epoch,time.perf_counter(),t_start_epoch)      
+
+    def runONEepoch_onlyTrain(self,epoch):
+        '''
+        Run one epoch with all the specified parameters.
+        epoch: (int) that specifies which epoch we are training.
+        '''
+
+        # Start timer to count epoch time.
+        t_start_epoch = time.perf_counter()                 
+                
+        # Train model        
+        training=True                 
+        train_results = TrainValidateTest.train(self,self.Train_indices,self.optimizer,training,self.saveClusters,self.labels)                       
+
+        # Scheduler step
+        self.scheduler.step()      
+
+        # Show epoch information and save it into a file
+        self.dict_epoch = utilz.showAndSaveEpoch(self,train_results,train_results,self.fold,epoch,time.perf_counter(),t_start_epoch)      
         
     
     def test(self):
@@ -391,7 +410,7 @@ class NaroNet:
                                 for epoch in range(1, self.args['epochs'] + 1):            
                                     
                                     # Train 1 epoch
-                                    self.runONEepoch(epoch)                
+                                    self.runONEepoch_onlyTrain(epoch)                
 
                                     # Save stats
                                     bar_epochs.update(1)
