@@ -135,7 +135,7 @@ class SimCLR(object):
                 gc.collect(0)
                 gc.collect(1)
                 gc.collect(2)
-            logging.debug(f"Epoch: {epoch_counter}\tLoss: {loss}\tTop1 accuracy: {top1[0]}")
+                logging.debug(f"Epoch: {epoch_counter}\tLoss: {loss}\tTop1 accuracy: {top1[0]}\tTop5 accuracy: {top5[0]}")
 
             # warmup for the first 10 epochs
             if epoch_counter >= 6*(self.args['PCL_Epochs']/10):
